<?php

###############################################################################
# ukrainian.php
# This is the ukrainian language page for GeekLog!
#
#
# Ukrainian language is so rich and versatile! 
# Please, email me your comments and suggestions
#
#
# Copyright (C) 2006 Vitaliy Biliyenko
# v.lokki@gmail.com
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

$LANG_CHARSET = 'Windows-1251';

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

###############################################################################
# USER PHRASES - These are file phrases used in end user scripts
###############################################################################

###############################################################################
# lib-common.php

$LANG01 = array(
    1 => '():',
    2 => ' ',
    3 => '',
    4 => '',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => ' :',
    10 => ' ',
    11 => '',
    12 => '',
    13 => '',
    14 => '',
    15 => '',
    16 => '',
    17 => '',
    18 => ' SQL',
    19 => ' ',
    20 => '  :',
    21 => '\' ',
    22 => 'ID ',
    23 => 'г ',
    24 => '',
    25 => '³',
    26 => '        .       .',
    27 => ' ',
    28 => '',
    29 => ' .',
    30 => ' ',
    31 => '  HTML:',
    32 => ':  \' ',
    33 => ':     ',
    34 => '',
    35 => '  ',
    36 => '',
    37 => '  ',
    38 => ' ',
    39 => '',
    40 => '',
    41 => '',
    42 => ':',
    43 => '³',
    44 => '',
    45 => '  MySQL',
    46 => '   MySQL',
    47 => 'i ',
    48 => '̳  ',
    49 => '',
    50 => '   SQL',
    51 => '',
    52 => '',
    53 => '',
    54 => '  .',
    55 => ' ',
    56 => '',
    57 => '',
    58 => '',
    59 => "   ?    <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\"> </a>",
    60 => ' ',
    61 => '   ',
    62 => '',
    63 => ' ',
    64 => '³   ',
    65 => '   ',
    66 => '',
    67 => '   ',
    68 => '',
    69 => '',
    70 => '',
    71 => '',
    72 => ' ',
    73 => '',
    74 => '',
    75 => ' ',
    76 => ' ',
    77 => '',
    78 => '',
    79 => ' ',
    80 => '  ',
    81 => '  ',
    82 => '()',
    83 => 'i',
    84 => '',
    85 => '  48 ',
    86 => '  ',
    87 => '  2 ',
    88 => '',
    89 => '',
    90 => '',
    91 => '  ',
    92 => '',
    93 => ' ',
    94 => '           .',
    95 => '  ',
    96 => '',
    97 => ' ',
    98 => '',
    99 => '',
    100 => '  ',
    101 => '',
    102 => '',
    103 => 'ﳿ  ',
    104 => '',
    105 => ' ',
    106 => '',
    107 => '  Geeklog',
    108 => ' ',
    109 => '  ',
    110 => '    ',
    111 => '',
    112 => ' ',
    113 => '',
    114 => '',
    115 => '  -',
    116 => '',
    117 => '',
    118 => '-,     :',
    119 => " <a href=\"{$_CONF['site_url']}/users.php?mode=getpassword\" rel=\"nofollow\"></a>?",
    120 => '    ',
    121 => ' (%d)',
    122 => ' (%d)',
    123 => ' HTML ',
    124 => '     ',
    125 => ' ,      ?',
    126 => '/    ',
    127 => 'Permalink',
    128 => 'Login with OpenID:',
    129 => 'Configuration',
    130 => 'Webservices'
);

###############################################################################
# comment.php

$LANG03 = array(
    1 => ' ',
    2 => ' ',
    3 => '',
    4 => '  ',
    5 => '\' ',
    6 => '   ,    .     ,     .',
    7 => '    ',
    8 => "  . ,        {$_CONF['commentspeedlimit']} ",
    9 => '',
    10 => '³ ',
    11 => ' ',
    12 => '-,     ,       .',
    13 => ' ',
    14 => ' ',
    15 => '   ',
    16 => '',
    17 => '',
    18 => ' ',
    19 => '-,   .',
    20 => '         .',
    21 => '  ,      ,   .',
    22 => ' ,      .',
    23 => '     .',
    24 => ' ',
    25 => ' ,       ?',
    26 => '%s     :',
    27 => '  ',
    28 => 'Preview Changes',
    29 => 'Submit Changes',
    30 => 'Edited on',
    31 => 'by',
    32 => 'Editing a Comment',
    33 => 'Editing a Comment Submission',
    34 => 'Preview Submission Changes',
    35 => 'Save Changes to Queue',
    36 => 'Notify me of new replies',
    37 => 'New Comment Reply',
    38 => 'A reply has been made to your comment \'%s\'.',
    39 => 'You may view the comment thread at the following address:',
    40 => 'If you wish to receive no further notifications of replies, visit the following link:',
    41 => 'Hello %s,',
    42 => 'Unsubscribe',
    43 => 'Unsubscribe from reply notifications',
    44 => 'Your Name'
);

###############################################################################
# users.php

$LANG04 = array(
    1 => '  ',
    2 => '\' ',
    3 => ' \'',
    4 => ' ',
    5 => ' ',
    6 => ' ',
    7 => '',
    8 => ' PGP',
    9 => ' ',
    10 => ' 10  ',
    11 => '  ',
    12 => ' ',
    13 => '   ',
    14 => '  .    .       "̳  "   .',
    15 => "    {$_CONF['site_name']}  .         '  . -,    ,      .",
    16 => '  ',
    17 => '   ',
    18 => '   ',
    19 => '    \'   ',
    20 => '   ',
    21 => '',
    22 => "  {$_CONF['site_name']}!",
    23 => "          {$_CONF['site_name']}          '.    ,     . ,     <b><i></i></b>       .",
    24 => '     .',
    25 => ' ?',
    26 => ' <em></em>  , <em></em>  ,        .          .',
    27 => ' !',
    28 => ' ',
    29 => ' ',
    30 => ' ',
    31 => '    ,   ',
    32 => 'ϳ',
    33 => 'ͳ   ',
    34 => '   \'',
    35 => '  ,    ',
    36 => '   http://',
    37 => '  ',
    38 => '  ,   ',
    39 => '  PGP  ',
    40 => '  ',
    41 => ' ',
    42 => ' ',
    43 => '  ',
    44 => ' ',
    45 => '  ',
    46 => '  ',
    47 => '   ',
    48 => '',
    49 => '    ',
    50 => ' ,     ',
    51 => '³  ',
    52 => ' ',
    53 => '    ',
    54 => '³   ,     .',
    55 => '    ,  ,      .     ,     ,   ,      .      .',
    56 => '',
    57 => ' ',
    58 => ' ',
    59 => ' ',
    60 => '     ?',
    61 => '³     ?',
    62 => '  100',
    63 => "      . -,    .     {$_CONF['site_name']}",
    64 => '  ',
    65 => '     ',
    66 => '     . -,   .',
    67 => '',
    68 => '\'  ',
    69 => '    \'      ?',
    70 => "      {$_CONF['site_name']}",
    71 => "       ,   ,     .    ,    <a href=\"{$_CONF['site_url']}/users.phpmode=new\" rel=\"nofollow\"></a>  {$_CONF['site_name']}.   ?         !",
    72 => ' ',
    73 => '',
    74 => '  !',
    75 => '   ',
    76 => '     ,    ,         .    ,   !',
    77 => '',
    78 => '  !',
    79 => '  ,  ',
    80 => '',
    81 => ' ',
    82 => ' 10   ',
    83 => '   ',
    84 => 'ʳ :',
    85 => 'ʳ :',
    86 => ' i  i',
    87 => ' ',
    88 => " ( )        \"%s\"  {$_CONF['site_name']}, <{$_CONF['site_url']}>.\n\n    , -,   :\n\n",
    89 => "    ,        (   ). \n\n",
    90 => '     . -,    ,          .',
    91 => '  ',
    92 => '  ',
    93 => '       %d  .    %d      .',
    94 => '   "%s"',
    95 => ' "  ",       . ,   ,      <strong></strong>  ,    "".',
    96 => '  ',
    97 => 'ϳ  ',
    98 => ' ,     ?  ,        (    ).   ,  " " .',
    99 => '  ',
    100 => '  ',
    101 => '    ',
    102 => '  ',
    103 => '    ',
    104 => '³ -',
    105 => '³   " "',
    106 => '̳ ',
    107 => '³   ',
    108 => 'ϳ  ',
    109 => '    ',
    110 => ' ',
    111 => '-,    ',
    112 => '     . -,    .',
    113 => '  ',
    114 => '  ',
    115 => '   ,    . -,   .',
    116 => '    ',
    117 => '       .    ,     .',
    118 => "    {$_CONF['site_name']}  .       ,  ,    (<username>)     .",
    119 => '   ,       :',
    120 => '  ',
    121 => '',
    122 => ',    ',
    123 => " <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\"> </a>?",
    124 => 'ϳ  ',
    125 => '        !',
    126 => '-,   ',
    127 => '   ,     .',
    128 => ' \'',
    129 => '   ',
    130 => ' ',
    131 => '  ',
    132 => ' ',
    133 => '³ ',
    134 => ' ',
    135 => '<li>    </li><li>    </li><li>     ,   - 100</li>',
    136 => '   ',
    137 => 'Գ  ',
    138 => ' ',
    139 => '   ',
    140 => '<li>   -      </li><li>  -    ,    <li>     </li><li>     </li>',
    141 => ' ',
    142 => '             -. ³  ,     .',
    143 => 'Գ  ',
    144 => '/ ',
    145 => '  ',
    146 => '   ',
    147 => '  ,     .          .',
    148 => '  ',
    149 => '   ,     .<li>ϳ         </li><li> -    ,      </li><li>   PGP</li>',
    150 => ':      Javascript',
    156 => '  ',
    157 => ' ',
    158 => 'Time Zone',
    159 => 'This email was generated automatically. Please do not reply to this email.',
    160 => '(max. %d x %d pixels, %d bytes; %s)',
    161 => 'will be scaled down',
    162 => 'will not be scaled',
    163 => 'Re-Authentication Failed',
    164 => 'You have exceeded the number of allowed attempts for re-authentication. The operation has been aborted and your recent changes were lost, sorry.',
    165 => 'Use Advanced Editor'
);

###############################################################################
# Customize if need to modify the Tabbed navbar MyAccount panels used.
# Array index key matches preference div id

$LANG_MYACCOUNT = array(
    'pe_preview' => 'Preview',
    'pe_namepass' => 'Username &amp; Password',
    'pe_userinfo' => 'About You',
    'pe_layout' => 'Layout &amp; Language',
    'pe_content' => 'Content',
    'pe_privacy' => 'Privacy'
);

###############################################################################
# index.php

$LANG05 = array(
    1 => '   ',
    2 => '    .            ',
    3 => '   %s',
    4 => '  ',
    5 => '',
    6 => '',
    7 => '',
    8 => ''
);

###############################################################################
# profiles.php

$LANG08 = array(
    1 => 'ϳ     .   .',
    2 => '  .',
    3 => '     ³.',
    4 => ' : \', ³, , ',
    5 => ':   .',
    6 => ' .',
    7 => ' ',
    8 => '\' ',
    9 => 'URL ',
    10 => '  ',
    11 => ' \':',
    12 => '³:',
    13 => ':',
    14 => ':',
    15 => 'HTML   .',
    16 => ' ',
    17 => '  ',
    18 => '³',
    19 => ' ',
    20 => '',
    21 => ' ',
    22 => '  \'',
    23 => "    %s  %s   () (),       {$_CONF['site_url']}.      ,    ,     .",
    24 => '    ',
    25 => '   ,     .        ',
    26 => '        .   \'.',
    27 => ' ',
    28 => '%s (): ',
    29 => "    {$_CONF['site_name']}  ",
    30 => '     ',
    31 => '',
    32 => '',
    33 => '   ',
    34 => 'ʳ ',
    35 => ',       .',
    36 => 'Copy:',
    37 => 'Send me a copy of this email',
    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:",
    39 => 'Your last message was ',
    40 => " seconds ago.  This site requires at least {$_CONF['speedlimit']} seconds between sending messages"
);

###############################################################################
# search.php

$LANG09 = array(
    1 => ' ',
    2 => 'i ',
    3 => '',
    4 => '',
    5 => '',
    6 => 'i',
    7 => 'i',
    8 => '',
    9 => '',
    10 => '',
    11 => ' ',
    12 => 'i(,)',
    13 => ' : ii ',
    14 => '   i   ',
    15 => '-,   .',
    16 => '',
    17 => '',
    18 => '',
    19 => "  i i  i i  {$_CONF['site_name']}",
    20 => '',
    21 => '',
    22 => '(  -MM-)',
    23 => 'i',
    24 => ' %d \'():',
    25 => '',
    26 => 'i ',
    27 => '',
    28 => ' i       ',
    29 => '    i',
    30 => '',
    31 => '     ',
    32 => '',
    33 => 'URL',
    34 => '',
    35 => ' ',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => '   i i 3 .',
    42 => '    - -MM- (i-i-).',
    43 => ' ',
    44 => ' i ',
    45 => ' - i i',
    46 => '',
    47 => 'i',
    48 => '',
    49 => '',
    50 => 'i',
    51 => '',
    52 => '',
    53 => '  ',
    54 => '  ',
    55 => '',
    56 => 'AND',
    57 => 'OR',
    58 => '  &gt;&gt;',
    59 => '',
    60 => ' ',
    61 => ' ',
    62 => '#',
    63 => 'Description',
    64 => 'Showing %1$d - %2$d of %3$d results',
    65 => 'Story',
    66 => 'Comment',
    67 => 'Show %d Results',
    68 => 'Sort By',
    69 => 'Titles Only',
    70 => 'Not available ...',
    71 => 'asc',
    72 => 'desc'
);

###############################################################################
# stats.php

$LANG10 = array(
    1 => ' ',
    2 => '   ',
    3 => ' ()  ',
    4 => '',
    5 => '',
    6 => '',
    7 => '  ',
    8 => ' ',
    9 => '',
    10 => '        .',
    11 => '   ',
    12 => '',
    13 => '        .',
    14 => '',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => '',
    22 => ' ,   ',
    23 => ' ',
    24 => ',         ',
    25 => '10  - ',
    26 => '  -.',
    27 => 'ʳ  ',
    28 => '',
    29 => '',
    30 => 'ճ',
    31 => ''
);

###############################################################################
# article.php

$LANG11 = array(
    1 => 'Ci',
    2 => '³  ',
    3 => '   ',
    4 => '',
    5 => '',
    6 => 'Subscribe to \'%s\''
);

###############################################################################
# submit.php

$LANG12 = array(
    1 => '      .',
    2 => '',
    3 => ' ',
    4 => '',
    5 => '',
    6 => ' ',
    7 => '   \'',
    8 => '',
    9 => '         ,    ...<ul><li> \'   <li>     <li>   URL,  </li></ul>',
    10 => '',
    11 => '',
    12 => ' ',
    13 => ' ',
    14 => '̳ ',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '   ',
    20 => '',
    21 => '',
    22 => ':  ',
    23 => '-,    .    \'.',
    24 => ' ',
    25 => '   .',
    26 => ' ',
    27 => '\' ',
    28 => '',
    29 => '',
    30 => '    ',
    31 => "  .    {$_CONF['speedlimit']}   ",
    32 => ' ',
    33 => '  ',
    34 => '  ',
    35 => ' HTML  ',
    36 => ' ',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => '',
    42 => '',
    43 => '',
    44 => ',  1',
    45 => ',  2',
    46 => '̳/',
    47 => '',
    48 => '',
    49 => '',
    50 => '',
    51 => '',
    52 => '',
    53 => '  ',
    54 => 'Story Introduction',
    55 => 'Story Body'
);

###############################################################################
# ADMIN PHRASES - These are file phrases used in admin scripts
###############################################################################

###############################################################################
# admin/auth.inc.php

$LANG20 = array(
    1 => ' ',
    2 => '³!   ',
    3 => '  ',
    4 => '\' :',
    5 => ':',
    6 => '        . <br' . XHTML . '>      .',
    7 => ''
);

###############################################################################
# admin/block.php

$LANG21 = array(
    1 => '  ',
    2 => '       .',
    3 => ' ',
    4 => '     .  error.log,   .',
    5 => '',
    6 => '',
    7 => '',
    8 => 'г ',
    9 => ' ',
    10 => '',
    11 => ' ',
    12 => ' ',
    13 => '  ',
    14 => 'RSS URL',
    15 => '  RSS',
    16 => '  ',
    17 => ' ',
    18 => ' :     ',
    19 => ' ',
    20 => '',
    21 => 'г  ',
    22 => '',
    23 => ' ',
    24 => '',
    25 => '    ,     .     ,  " " .   ,     [R]  [L].',
    26 => ' ',
    27 => ' PHP',
    28 => '  PHP',
    29 => ' ',
    30 => '  ,      PHP ,  \' .       "phpblock_" (, phpblock_getweather).      ,     .    ,    ,     Geeklog,  ,     .     "()"    .       /path/to/geeklog/system/lib-custom.php.            Geeklog.',
    31 => '   PHP.  %s  .',
    32 => ' () ()',
    33 => ' URL RSS    ',
    34 => '     PHP ',
    35 => '      ',
    36 => '    ',
    37 => ' \'    PHP',
    38 => '   PHP    \'phpblock_\' (, phpblock_getweather).  \'phpblock_\'         .',
    39 => '',
    40 => '˳',
    41 => '',
    42 => '      ',
    43 => '  ',
    44 => '',
    45 => "     ,      .    . -, <a href=\"{$_CONF['site_admin_url']}/block.php\">     </a>.",
    46 => '',
    47 => '',
    48 => ' ',
    49 => ' (     )',
    50 => 'The Block Name can not be empty',
    51 => ' http://',
    52 => '     ,       ',
    53 => '',
    54 => '',
    55 => '',
    56 => '',
    57 => '  ',
    58 => '  ',
    59 => '  ',
    60 => '  ',
    61 => ' ',
    62 => ' ',
    63 => ' ',
    64 => '        HTML!',
    65 => '',
    66 => '',
    67 => '³,    ',
    68 => 'The feed for this portal block is too long to display. Please set a maximum number of articles to import for the block in the block setup screen, or a global maximum in Geeklog Configuration.'
);

###############################################################################
# admin/story.php

$LANG24 = array(
    1 => ' ',
    2 => ' ',
    3 => '',
    4 => ' ',
    5 => ' ',
    6 => '    ',
    7 => '',
    8 => '',
    9 => ' ',
    10 => '',
    11 => '',
    12 => 'ID',
    13 => '',
    14 => '',
    15 => '',
    16 => '',
    17 => ' ',
    18 => '(,i)',
    19 => '(,)',
    20 => 'ϳ',
    21 => ' ',
    22 => ' ',
    23 => '    ,     .   ,   .    ,  " " .',
    24 => 'ID,      ,  . -,   ID.',
    25 => '    ',
    26 => '  ',
    27 => '   [unscaledX]  [imageX],      .',
    28 => '<p><b>Ͳ </b>:     ,    ,    .        .',
    29 => '',
    30 => '  ',
    31 => '-,     ',
    32 => '',
    33 => '     ',
    34 => '',
    35 => '',
    36 => 'ͳ',
    37 => ' ',
    38 => ' ',
    39 => '',
    40 => '',
    41 => "     ,      .    .     . -, <a href=\"{$_CONF['site_admin_url']}/story.php\">       </a>  .",
    42 => "     ,      .    . -, <a href=\"{$_CONF['site_admin_url']}/story.php\">    </a>.",
    43 => '',
    44 => '',
    45 => '',
    46 => '<b>:</b>         ,         .   ,         RSS         .',
    47 => '',
    48 => '',
    49 => '',
    50 => '',
    51 => '       \'   ,      .      [imageX], [imageX_right]  [imageX_left],  X     ,   \'. :    ,   \'.       .<BR>',
    52 => '',
    53 => '  .          ,     ',
    54 => 'ϳ\'   ',
    55 => '     .  -,    ',
    56 => '  ',
    57 => '    ',
    58 => ' ',
    59 => '',
    60 => '',
    61 => ' ',
    62 => ' ',
    63 => 'Disable Comments',
    64 => '',
    65 => '',
    66 => '',
    67 => '   ',
    68 => '   ',
    69 => '  ',
    70 => '  ',
    71 => ' ',
    72 => ' ',
    73 => ' ',
    74 => '  II',
    75 => ' ',
    76 => ' ',
    77 => '       Javascript.       config.php',
    78 => ' <a href="%s/story.php?mode=edit&amp;sid=%s&amp;editopt=default"></a>,    ',
    79 => '',
    80 => '',
    81 => ' ',
    82 => '',
    83 => ' ',
    84 => ' ',
    85 => ' ',
    86 => ' ',
    87 => ' ',
    88 => 'Wiki-style format',
    89 => 'Meta Description',
    90 => 'Meta Keywords',
    91 => 'You can always hit "Preview" to extend the expiry time.'
);

###############################################################################
# admin/topic.php

$LANG27 = array(
    1 => ' ',
    2 => 'ID ',
    3 => ' ',
    4 => ' ',
    5 => '(  )',
    6 => '      \'     ',
    7 => '-,   ID    ',
    8 => ' ',
    9 => '    ,  .    ,  " " .         . ǳ (*)    .',
    10 => ' ',
    11 => '  ',
    12 => '³  ',
    13 => "     ,      .    . -, <a href=\"{$_CONF['site_admin_url']}/topic.php\">      </a>.",
    14 => ' ',
    15 => '',
    16 => ' ',
    17 => ' ',
    18 => '',
    19 => '',
    20 => '',
    21 => '',
    22 => ' ',
    23 => '       ',
    24 => '(*)',
    25 => ' ',
    26 => '       .      .',
    27 => '  ',
    28 => '',
    29 => '  ',
    30 => 'Stories in Topic'
);

###############################################################################
# admin/user.php

$LANG28 = array(
    1 => ' ',
    2 => 'ID ',
    3 => '\' ',
    4 => ' \'',
    5 => '',
    6 => 'г ',
    7 => ' ',
    8 => ' ',
    9 => '(  )',
    10 => '-,   \'    ',
    11 => ' ',
    12 => '    ,     .     ,     .   ,  " " .     ,    ,    ( *son*  *.edu)   .',
    13 => 'г ',
    14 => ' ',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => ' \'  .',
    22 => '',
    23 => ' ',
    24 => '  ',
    25 => '      Geeklog.        -       :  \', \' ,   .  ,  ,    .        .          ,     !',
    26 => '',
    27 => '',
    28 => '³   ',
    29 => '',
    30 => '',
    31 => ' ',
    32 => ' .  %d ,  %d ',
    33 => '',
    34 => ':      .',
    35 => '   ',
    36 => '()',
    37 => 'UID',
    38 => ' ',
    39 => ' ( )',
    40 => ' ',
    41 => '  ',
    42 => '',
    43 => '  ',
    44 => '  ',
    45 => '',
    46 => ' ',
    47 => '',
    48 => '  ',
    49 => ' ',
    50 => '³,      ',
    51 => ' ',
    52 => '<br' . XHTML . '>: " " -           .',
    53 => '',
    54 => ' ',
    55 => '    ,    <code>$_CONF[\'lastlogin\'] = true;</code>    config.php',
    56 => '-,   ,       " ".     ,    ,   "". ,       ,    ,     .',
    57 => ' ',
    58 => ' ',
    59 => ' ',
    60 => ',    ',
    61 => ' () ,       .',
    62 => ',    ',
    63 => ' () ,      24 ,      .',
    64 => ' ,         ',
    65 => ' ().',
    66 => ' ',
    67 => '̳  ',
    68 => ' ',
    69 => '̳ ',
    70 => '  ',
    71 => ' ',
    72 => '     ',
    73 => ' ,     Ѳ  ?',
    74 => ' ',
    75 => ',     ',
    76 => ' ()',
    77 => 'Email site login reminder to selected users',
    78 => 'Send Reminder',
    79 => 'No User selected for reminders',
    80 => 'Successfully sent Reminders',
    81 => 'Reminder to verify account for %s',
    82 => "Your account on {$_CONF['site_name']} has not been accesssed since %s and will be disabled if not accessed in the 30 days.",
    83 => "Your account on {$_CONF['site_name']} has not been used since it was created and will deleted soon if not accessed.",
    84 => "Your login name is: %s  for our site: {$_CONF['site_url']}",
    85 => 'If you have forgotten the password use the following link: %s',
    86 => 'Include',
    87 => 'Reminders',
    88 => 'Default Group',
    89 => 'Check to make this a default group for new users',
    90 => 'Apply "Default Group" change to existing user accounts'
);

###############################################################################
# admin/moderation.php

$LANG29 = array(
    1 => '',
    2 => '',
    3 => '',
    4 => '',
    10 => '',
    11 => ' ',
    12 => 'URL',
    13 => ' ',
    14 => '',
    15 => '',
    16 => '\' ',
    17 => ' \'',
    18 => ' ',
    34 => '',
    35 => '  ',
    36 => 'Parent or Comment',
    37 => '',
    38 => '',
    39 => '    ',
    40 => '  ',
    41 => 'Comment Submissions',
    42 => 'Username',
    43 => 'Auto-publish Comments?'
);

###############################################################################
# admin/mail.php

$LANG31 = array(
    1 => " {$_CONF['site_name']}",
    2 => 'i',
    3 => 'ii:',
    4 => '',
    5 => '',
    6 => ':',
    7 => 'i i',
    8 => 'ii',
    9 => '',
    10 => 'HTML',
    11 => 'i i!',
    12 => '',
    13 => '',
    14 => 'I  ',
    15 => '  ii : ',
    16 => 'i i i : ',
    17 => "<a href=\"{$_CONF['site_admin_url']}/mail.php\">  </a>",
    18 => '',
    19 => ':       ,      .',
    20 => "  <successcount>    - <failcount>.   ,     .     <a href=\"{$_CONF['site_admin_url']}/mail.php\">³  </a>  <a href=\"{$_CONF['site_admin_url']}/moderation.php\">    </a>.",
    21 => '³()',
    22 => 'i',
    23 => ' ',
    24 => ' ',
    25 => '--   --',
    26 => '         .'
);

###############################################################################
# admin/plugins.php

$LANG32 = array(
    1 => '    Geeklog    . ,     ,   <a href="http://www.geeklog.net" target="_blank">  Geeklog</a>,     ,   ,    . ,   ,        ,      ,    ,     .         ,            ,    Geeklog.  ,      .          .',
    2 => '   ',
    3 => '  ',
    4 => ' ',
    5 => ' ',
    6 => ':   !',
    7 => ',    ,  .  ,   ,  ',
    8 => '     ',
    9 => '     Geeklog.    <a href="http://www.geeklog.net">Geeklog</a>      .',
    10 => '<br' . XHTML . '><b>    .</b><br' . XHTML . '><br' . XHTML . '>',
    11 => '    ,     .     ,    .    ,      .    ,    .     , -,    .',
    12 => '\'     plugineditor()',
    13 => ' ',
    14 => ' ',
    15 => '',
    16 => ' ',
    17 => ' ',
    18 => ' Geeklog',
    19 => '',
    20 => '',
    21 => 'ͳ',
    22 => '',
    23 => '',
    24 => '',
    25 => '',
    26 => ' ',
    27 => ' ',
    28 => ' ',
    29 => ' Geeklog',
    30 => ' ?',
    31 => ' ,     ? ,      ,    .   ,  "".',
    32 => '<p><b> -    AutoLink</b></p>',
    33 => ' ',
    34 => '',
    35 => '',
    36 => '',
    37 => '',
    38 => '!',
    39 => 'Upload a plugin',
    40 => 'You can upload a plugin archive (.tar.gz, .tgz, .zip) directly here:',
    41 => 'Upload',
    42 => 'Click to update',
    99 => 'An unknown error occured',
    100 => 'Ok.',
    101 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
    102 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
    103 => 'The uploaded file was only partially uploaded.',
    104 => 'No file was uploaded.',
    105 => '(undefined error)',
    106 => 'Missing a temporary folder.',
    107 => 'Failed to write file to disk.',
    108 => 'File upload stopped by extension.'
);

###############################################################################
# admin/syndication.php

$LANG33 = array(
    1 => ' ',
    2 => '',
    3 => '',
    4 => '',
    10 => ' ',
    11 => ' ',
    12 => '',
    13 => '    ,     .   ,  " " .',
    14 => '',
    15 => '',
    16 => '\' ',
    17 => '',
    18 => ' ',
    19 => '',
    20 => '',
    21 => 'ͳ',
    22 => '<i>( )</i>',
    23 => ' ',
    24 => '  ',
    25 => ' ',
    26 => '',
    27 => ' ',
    28 => '(0 =  , 1 =  ,   =     .)',
    29 => '',
    30 => ' ',
    31 => '',
    32 => '',
    33 => '',
    34 => '',
    35 => '',
    36 => '  ',
    37 => '',
    38 => ':  ',
    39 => '-,   ,   \' .',
    40 => '-,      .',
    41 => '',
    42 => '',
    43 => '',
    44 => '',
    45 => '  ',
    46 => ' ',
    47 => '',
    48 => '',
    49 => ' ',
    50 => "³  URL  ({$_CONF['site_url']})",
    51 => '\'    ,     . -,  .',
    52 => ': \'   ',
    53 => 'All Frontpage Stories',
    54 => 'Please select the type of feed to create.',
    55 => 'Articles'
);

###############################################################################
# confirmation and error messages

$MESSAGE = array(
    1 => "     . -,     .    {$_CONF['site_name']}",
    2 => "     {$_CONF['site_name']}.     .    ,        .",
    3 => '',
    4 => '',
    5 => '      .',
    6 => '    .',
    7 => '    .',
    8 => '    .',
    9 => '   .',
    10 => '  .',
    11 => '   .',
    12 => '  .',
    13 => '  .',
    14 => ',    ,    ,  .',
    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => '   .',
    22 => '  .',
    23 => '',
    24 => '',
    25 => '',
    26 => '',
    27 => '  .',
    28 => '  .',
    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
    30 => '³  ',
    31 => '',
    32 => '',
    33 => '',
    34 => '',
    35 => '',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => ' ',
    41 => '',
    42 => '',
    43 => '',
    44 => '  !',
    45 => '  .',
    46 => '',
    47 => '',
    48 => "     {$_CONF['site_name']}.     .            .",
    49 => '   .',
    50 => '   .',
    51 => ' \'   . -,  .',
    52 => '    .',
    53 => '   . -,       .',
    54 => '     . -,   .',
    55 => '     ,    . -,    ,        .',
    56 => '       .',
    57 => '    .',
    58 => '    .',
    59 => '   .',
    60 => '  ',
    61 => ' %s:   ',
    62 => '- .',
    63 => 'ϳ   -  .',
    64 => ' -  .',
    65 => '   .',
    66 => '   .',
    67 => '      !',
    68 => '     .',
    69 => '   !',
    70 => '      .',
    71 => '          .',
    72 => 'ϳ     .      error.log.',
    73 => 'ϳ     .      error.log.',
    74 => 'ϳ  .',
    75 => '    POST .',
    76 => ' ,     ?',
    77 => ':<br' . XHTML . '>     - UTF-8.       . -,   mbstring  PHP    /.',
    78 => '-, ,       .',
    79 => ',    ,   ,      .',
    80 => ',    ,  .      ,      .',
    81 => ',      .  -,   .',
    82 => '     .  -,    .',
    83 => '   ,    ,     \',    .',
    84 => '    ,    .',
    85 => 'There was a problem sending the email.',
    86 => 'The OpenID server invalidated your login attempt.',
    87 => 'OpenID login operation cancelled by user.',
    88 => 'The OpenID server returned an error.',
    89 => 'Unable to find an OpenID server for the given identity URL.',
    90 => 'OpenID identification cancelled.',
    91 => 'You specified an invalid identity URL.',
    92 => "Please <a href=\"{$_CONF['site_admin_url']}/sectest.php\">check the security of your site</a> before using it!",
    93 => 'Database back up was successful.',
    94 => 'Backup Failed: Filesize less than 1kb',
    95 => 'There was an error.',
    96 => '',
    97 => '',
    98 => 'The plugin was successfully uploaded.',
    99 => 'The plugin already exists.',
    100 => 'The plugin file you uploaded was not a GZip or Zip compressed archive.',
    101 => 'There are no topics (that you have access to). You need at least one topic to be able to submit stories.',
    400 => 'Not all required fields have been passed validation',
    401 => 'Please enter Fullname'
);

###############################################################################

$LANG_ACCESS = array(
    'access' => '',
    'ownerroot' => '/Root',
    'group' => '',
    'readonly' => 'ҳ ',
    'accessrights' => ' ',
    'owner' => '',
    'grantgrouplabel' => '    ',
    'permmsg' => ':  -       ,   -    ,     .',
    'securitygroups' => ' ',
    'editrootmsg' => "     ,       ,       .      ,  .   ,       .  -,   <a href=\"{$_CONF['site_admin_url']}/user.php\">  </a>.",
    'securitygroupsmsg' => '      .',
    'groupeditor' => ' ',
    'description' => '',
    'name' => '\'',
    'rights' => '',
    'missingfields' => ' ',
    'missingfieldsmsg' => '      ',
    'groupmanager' => ' ',
    'newgroupmsg' => '    ,     .   ,  " " . ,       ,    .',
    'groupname' => '\' ',
    'coregroup' => ' ',
    'yes' => '',
    'no' => 'ͳ',
    'corerightsdescr' => "     {$_CONF['site_name']}.       .   ,    .",
    'groupmsg' => '   .     ,       ,    .    ,   ,     .        ,           "" .    -    ,      .',
    'coregroupmsg' => "     {$_CONF['site_name']}.  ,        .        .",
    'rightsdescr' => '        ,    . ҳ ,     ,  ,       ,    .         .',
    'lock' => '',
    'members' => '',
    'anonymous' => '',
    'permissions' => '',
    'permissionskey' => 'R = , E = ,      ',
    'edit' => '',
    'none' => '',
    'accessdenied' => '³  ',
    'storydenialmsg' => "        . ,       {$_CONF['site_name']}.  , <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\"></a>  {$_CONF['site_name']}    !",
    'nogroupsforcoregroup' => '        ',
    'grouphasnorights' => '           ',
    'newgroup' => ' ',
    'adminhome' => '',
    'save' => '',
    'cancel' => '',
    'delete' => '',
    'canteditroot' => '    ,        ,     .  ,   ,    .',
    'listusers' => '',
    'listthem' => '',
    'usersingroup' => '  "%s"',
    'usergroupadmin' => '  ',
    'add' => '',
    'remove' => '',
    'availmembers' => ' ',
    'groupmembers' => ' ',
    'canteditgroup' => '   ,     . -,   ,    .',
    'cantlistgroup' => '    ,      . -,   ,    .',
    'editgroupmsg' => '    ,  ()       .     ,       .    -  <b></b>,          .',
    'listgroupmsg' => '   : <b>%s</b>',
    'search' => '',
    'submit' => '³',
    'limitresults' => ' ',
    'group_id' => 'ID ',
    'plugin_access_denied_msg' => '       .  ,     .',
    'groupexists' => ' \'   ',
    'groupexistsmsg' => '     \'.     .'
);

###############################################################################
# admin/database.php

$LANG_DB_BACKUP = array(
    'last_ten_backups' => ' 10  ',
    'do_backup' => '  ',
    'backup_successful' => '     .',
    'db_explanation' => '        ,  ',
    'not_found' => "    mysqldump  .<br" . XHTML . ">  <strong>\$_DB_mysqldump_path</strong>   config.php.<br" . XHTML . ">  : <var>{$_DB_mysqldump_path}</var>",
    'zero_size' => '  :   0 ',
    'path_not_found' => "{$_CONF['backup_path']}      ",
    'no_access' => ":  {$_CONF['backup_path']} .",
    'backup_file' => '  ﳿ',
    'size' => '',
    'bytes' => '',
    'total_number' => '  : %d',
    'download' => 'Click to download this file',
    'new_backup' => 'New Backup',
    'delete_failure' => 'One or more backup files could not be deleted.',
    'delete_success' => 'Backup file(s) successfully deleted.',
    'convert_menu' => 'Convert to InnoDB',
    'convert_title' => 'Convert to InnoDB tables',
    'convert_button' => 'Convert',
    'sorry_no_innodb' => 'Sorry, your version of MySQL does not support InnoDB tables.',
    'innodb_explain' => 'InnoDB tables provide better performance on <em>really</em> large databases but make the backup process more complicated. Please <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">read up</a> on the pros and cons of InnoDB tables before you perform this operation.',
    'already_converted' => 'Note: It appears that all of the tables have already been converted to InnoDB.',
    'conversion_patience' => 'Note: Conversion may take some time - please be patient.',
    'innodb_success' => 'Successfully converted tables to InnoDB.',
    'table_issues' => 'There may have been problems with some tables, though. Please check error.log for details.',
    'optimize_menu' => 'Optimize Tables',
    'optimize_title' => 'Optimize Tables',
    'optimize_button' => 'Optimize',
    'optimize_explain' => 'Optimizing tables may help to improve the performance of your site. The actual impact depends on the table usage and some tables may benefit from it more than others. Do no expect to see a huge difference in performance. The <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manual</a> states: <q>it is not likely that you need to do this more than once a week or month</q>.',
    'last_optimization' => 'Last optimization',
    'optimization_patience' => 'Note: Optimization may take some time - please be patient.',
    'optimize_success' => 'Successfully optimized database tables.'
);

###############################################################################

$LANG_BUTTONS = array(
    1 => '',
    2 => '',
    3 => '',
    4 => '',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => '',
    10 => ' ',
    11 => ''
);

###############################################################################
# 404.php

$LANG_404 = array(
    1 => ' 404',
    2 => ',   ,     <b>%s</b>.',
    3 => "<p> ,  ,   ,  . -,  <a href=\"{$_CONF['site_url']}\"> </a>  <a href=\"{$_CONF['site_url']}/search.php\"> </a>     ."
);

###############################################################################
# login form

$LANG_LOGIN = array(
    1 => ' \'',
    2 => ',      ,   .',
    3 => '',
    4 => ' '
);

###############################################################################
# trackback.php

$LANG_TRB = array(
    'trackback' => '',
    'from' => '',
    'tracked_on' => ' ',
    'read_more' => '[ ]',
    'intro_text' => '      \'%s\':',
    'no_comments' => ' -   .',
    'this_trackback_url' => '-URL   :',
    'num_comments' => '%d -',
    'send_trackback' => ' ',
    'preview' => '',
    'editor_title' => ' -',
    'trackback_url' => '-URL',
    'entry_url' => 'URL ',
    'entry_title' => ' ',
    'blog_name' => ' ',
    'excerpt' => '',
    'truncate_warning' => ': -    ',
    'button_send' => '',
    'button_preview' => '',
    'send_error' => '',
    'send_error_details' => '    -:',
    'url_missing' => ' URL ',
    'url_required' => '-,    URL  .',
    'target_missing' => ' -URL',
    'target_required' => '-,  -URL',
    'error_socket' => '   .',
    'error_response' => '³ .',
    'error_unspecified' => ' .',
    'select_url' => ' -URL',
    'not_found' => '-URL  ',
    'autodetect_failed' => 'Geeklog    -URL  ,      . -,    .',
    'trackback_explain' => '  ,  URL       -. Geeklog    -URL   .    <a href="%s">  ,</a>    .',
    'no_links_trackback' => '  .     -   .',
    'pingback' => 'ϳ',
    'pingback_results' => ' ',
    'send_pings' => ' ',
    'send_pings_for' => '   "%s"',
    'no_links_pingback' => '  .       .',
    'pingback_success' => 'ϳ .',
    'no_pingback_url' => '  -URL.',
    'resend' => '',
    'ping_all_explain' => '    ,    (<a href="http://en.wikipedia.org/wiki/Pingback">ϳ</a>),       ,   <a href="http://en.wikipedia.org/wiki/Trackback"></a>-,        .',
    'pingback_button' => ' ',
    'pingback_short' => '    ,     .',
    'pingback_disabled' => '(ϳ )',
    'ping_button' => ' ',
    'ping_short' => 'ϳ  .',
    'ping_disabled' => '(ϳ )',
    'trackback_button' => ' ',
    'trackback_short' => ' -.',
    'trackback_disabled' => '( )',
    'may_take_a_while' => ',        .',
    'ping_results' => ' ',
    'unknown_method' => '  ',
    'ping_success' => 'ϳ .',
    'error_site_name' => '-,   .',
    'error_site_url' => '-,  URL .',
    'error_ping_url' => '-,   -URL.',
    'no_services' => '    .',
    'services_headline' => ' ',
    'service_explain' => '    ,    .    ,  " " .',
    'service' => '',
    'ping_method' => ' ',
    'service_website' => '',
    'service_ping_url' => 'ϳ URL',
    'ping_standard' => ' ',
    'ping_extended' => ' ',
    'ping_unknown' => '( )',
    'edit_service' => '  ',
    'trackbacks' => '',
    'editor_intro' => 'ϳ  -  <a href="%s">%s</a>.',
    'editor_intro_none' => 'ϳ  -.',
    'trackback_note' => '  -  ,       " "  .   ,  \'  ,  <a href="%s"></a>.',
    'pingback_explain' => ' URL,     . ϳ       .',
    'pingback_url' => 'ϳ-URL',
    'site_url' => 'URL  ',
    'pingback_note' => '    ,       " "  .   ,  \'  ,  <a href="%s"></a>.',
    'pbtarget_missing' => ' -URL',
    'pbtarget_required' => '-,  -URL',
    'pb_error_details' => '    :',
    'delete_trackback' => '   , : '
);

###############################################################################
# directory.php

$LANG_DIR = array(
    'title' => ' ',
    'title_year' => '   %d',
    'title_month_year' => '   %s %d',
    'nav_top' => '   ',
    'no_articles' => ' .'
);

###############################################################################
# admin/sectest.php

$LANG_SECTEST = array(
    'sectest' => 'Geeklog Security Check',
    'results' => 'Results of the Security Check',
    'okay' => 'Everything seems to be in order.',
    'please_fix' => 'Please fix the above issues before using your site!',
    'please_note' => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
    'stay_informed' => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) %s mailing list and/or use the %s option in your Admin menu from time to time to check for available updates.',
    'public_html' => '"public_html" should never be part of your site\'s URL.  Please read the part about public_html in the %s again and change your setup accordingly before you proceed.',
    'installation' => 'installation instructions',
    'directory' => 'directory',
    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
    'fix_it' => 'This is a security risk and should be fixed!',
    'reachable' => 'Your %s is reachable from the web.',
    'not_reachable' => 'Good! Your %s is not reachable from the web.',
    'not_sure' => 'Got an HTTP result code %s when trying to test your %s. Not sure what to make of it ...',
    'remove_inst' => 'You should really remove the install directory %s once you have your site up and running without any errors.',
    'remove_inst2' => 'Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
    'inst_removed' => 'Good! You seem to have removed the install directory already.',
    'fix_password' => 'You still have not changed the <strong>default password</strong> from "password" on %s Root user account(s).',
    'password_okay' => 'Good! You seem to have changed the default account password already.'
);

###############################################################################
# "What's New" Time Strings
# 
# For the first two strings, you can use the following placeholders.
# Order them so it makes sense in your language:
# %i    item, "Stories"
# %n    amount, "2", "20" etc.
# %t    time, "2" (weeks)
# %s    scale, "hrs", "weeks"

$LANG_WHATSNEW = array(
    'new_string' => '%n  %i   %t %s',
    'new_last' => ' %t %s',
    'minutes' => '',
    'hours' => '',
    'days' => '',
    'weeks' => '',
    'months' => '',
    'years' => 'years',
    'minute' => '',
    'hour' => '',
    'day' => '',
    'week' => '',
    'month' => '',
    'year' => 'year'
);

###############################################################################
# Month names

$LANG_MONTH = array(
    1 => 'ѳ',
    2 => '',
    3 => '',
    4 => '',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => '',
    10 => '',
    11 => '',
    12 => ''
);

###############################################################################
# Weekdays

$LANG_WEEK = array(
    1 => '',
    2 => '',
    3 => '³',
    4 => '',
    5 => '',
    6 => '\'',
    7 => ''
);

###############################################################################
# Admin - Strings
# 
# These are some standard strings used by core functions as well as plugins to
# display administration lists and edit pages

$LANG_ADMIN = array(
    'search' => '',
    'limit_results' => ' ',
    'submit' => '',
    'edit' => '',
    'edit_adv' => 'Adv. Edit',
    'admin_home' => '',
    'create_new' => ' ',
    'create_new_adv' => 'Create New (Adv.)',
    'enabled' => '',
    'title' => '',
    'page_title' => 'Page Title',
    'type' => '',
    'topic' => '',
    'help_url' => 'URL  ',
    'save' => '',
    'cancel' => '',
    'delete' => '',
    'delete_sel' => 'Delete selected',
    'copy' => '',
    'no_results' => '-    -',
    'data_error' => 'ϳ     . -,   .',
    'preview' => ' ',
    'records_found' => ' ',
    'addchild' => 'Add child',
    'list' => 'list',
    'list_all' => 'List all',
    'meta_description' => 'Meta Description',
    'meta_keywords' => 'Meta Keywords',
    'na' => 'N/A',
    'token_expiry' => 'You have until %s to make changes. After that time, the security token embedded into this page will expire and you will lose your changes.',
    'token_expired' => 'The security token for this operation has expired. Please authenticate again to continue.',
    'reauth_msg' => 'The security token for this operation has expired. If you want to continue with this operation, then please authenticate again below. This will ensure that the changes you just made will not be lost.',
    'authenticate' => 'Authenticate'
);

# Localisation of the texts for the various drop-down menus that are actually
# stored in the database. If these exist, they override the texts from the
# database.

$LANG_commentcodes = array(
    0 => ' ',
    -1 => ' ',
    1 => 'Comments Closed'
);

$LANG_commentmodes = array(
    'flat' => '',
    'nested' => '',
    'threaded' => '',
    'nocomment' => ' '
);

$LANG_cookiecodes = array(
    0 => '( )',
    3600 => '1 ',
    7200 => '2 ',
    10800 => '3 ',
    28800 => '8 ',
    86400 => '1 ',
    604800 => '1 ',
    2678400 => '1 '
);

$LANG_dateformats = array(
    0 => ''
);

$LANG_featurecodes = array(
    0 => '',
    1 => ''
);

$LANG_frontpagecodes = array(
    0 => '   ',
    1 => '  '
);

$LANG_postmodes = array(
    'plaintext' => ' ',
    'html' => ' HTML'
);

$LANG_sortcodes = array(
    'ASC' => ' ',
    'DESC' => ' '
);

$LANG_trackbackcodes = array(
    0 => ' ',
    -1 => ' '
);

###############################################################################
# Localization of the Admin Configuration UI

$LANG_CONFIG = array(
    'home' => 'Home',
    'admin_home' => 'Site Administration',
    'sections' => 'Configuration Sections',
    'restore' => 'Restore',
    'add_element' => 'Add Element',
    'save_changes' => 'Save Changes',
    'reset_form' => 'Reset Form',
    'changes_made' => 'Changes were successfully made to',
    'title' => 'Configuration Manager',
    'disable' => 'Click to disable this option',
    'enable' => 'Enable'
);

$LANG_configsections['Core'] = array(
    'label' => 'Geeklog',
    'title' => 'Geeklog Configuration'
);

$LANG_confignames['Core'] = array(
    'path_html' => 'HTML Path',
    'site_url' => 'Site URL',
    'site_admin_url' => 'Admin URL',
    'site_mail' => 'Site E-Mail',
    'noreply_mail' => 'No-Reply E-Mail',
    'site_name' => 'Site Name',
    'site_slogan' => 'Slogan',
    'microsummary_short' => 'Microsummary',
    'path_log' => 'Log',
    'path_language' => 'Language',
    'backup_path' => 'Backup',
    'path_data' => 'Data',
    'path_images' => 'Images',
    'path_pear' => 'Path Pear',
    'have_pear' => 'Have Pear?',
    'mail_settings' => 'Mail Settings',
    'allow_mysqldump' => 'Allow MySQL Dump',
    'mysqldump_path' => 'Path of Executable',
    'mysqldump_options' => 'MySQL Dump Options',
    'mysqldump_filename_mask' => 'Backup File Name Mask',
    'theme' => 'Theme',
    'doctype' => 'DOCTYPE Declaration',
    'menu_elements' => 'Menu Elements',
    'path_themes' => 'Themes Path',
    'disable_new_user_registration' => 'Disable New Registrations',
    'allow_user_themes' => 'Allow User Themes',
    'allow_user_language' => 'Allow User Language',
    'allow_user_photo' => 'Allow User Photo',
    'allow_username_change' => 'Allow Username Changes',
    'allow_account_delete' => 'Allow Account Deletion',
    'hide_author_exclusion' => 'Allow Hide Author',
    'show_fullname' => 'Show Fullname',
    'show_servicename' => 'Show Service Name',
    'custom_registration' => 'Enable Custom Registration',
    'user_login_method' => 'User Login Method',
    'spamx' => 'Spam-X Actions',
    'sort_admin' => 'Sort Links',
    'language' => 'Language',
    'locale' => 'Locale',
    'date' => 'Date Format',
    'daytime' => 'Daytime Format',
    'shortdate' => 'Short Date Format',
    'dateonly' => 'Date Only Format',
    'timeonly' => 'Time Only Format',
    'week_start' => 'Week Start',
    'hour_mode' => 'Hour Mode',
    'thousand_separator' => 'Thousands Separator',
    'decimal_separator' => 'Decimal Separator',
    'decimal_count' => 'Decimal Count',
    'language_files' => 'Language Files',
    'languages' => 'Languages',
    'timezone' => 'Timezone',
    'site_disabled_msg' => 'Site Disabled Message or URL',
    'rootdebug' => 'Root Debugging',
    'cookie_session' => 'Session Cookie Name',
    'cookie_name' => 'Permanent Cookie Name',
    'cookie_password' => 'Password Cookie Name',
    'cookie_theme' => 'Theme Cookie Name',
    'cookie_language' => 'Language Cookie Name',
    'cookie_tzid' => 'Timezone Cookie Name',
    'cookie_anon_name' => 'Anon. Username Cookie Name',
    'cookie_ip' => 'Cookies embed IP?',
    'default_perm_cookie_timeout' => 'Permanent Timeout',
    'session_cookie_timeout' => 'Session Timeout',
    'cookie_path' => 'Cookie Path',
    'cookiedomain' => 'Cookie Domain',
    'cookiesecure' => 'Cookie Secure',
    'lastlogin' => 'Record Last Login?',
    'num_search_results' => 'Number of Search Results',
    'loginrequired' => 'Login Required?',
    'submitloginrequired' => 'Submit Login Required?',
    'commentsloginrequired' => 'Comment Login Required?',
    'statsloginrequired' => 'Stats Login Required?',
    'searchloginrequired' => 'Search Login Required?',
    'profileloginrequired' => 'Profile Login Required?',
    'emailuserloginrequired' => 'E-Mail User Login Required?',
    'emailstoryloginrequired' => 'E-Mail Story Login Required?',
    'directoryloginrequired' => 'Directory Login Required?',
    'storysubmission' => 'Story Submission Queue?',
    'usersubmission' => 'User Submission Queue?',
    'listdraftstories' => 'List Draft Stories?',
    'notification' => 'Notifications',
    'postmode' => 'Default Post Mode',
    'speedlimit' => 'Post Speed Limit',
    'skip_preview' => 'Skip Preview in Posts',
    'advanced_editor' => 'Advanced Editor?',
    'wikitext_editor' => 'Wikitext Editor?',
    'cron_schedule_interval' => 'Cron Schedule Interval',
    'sortmethod' => 'Sort Topics',
    'showstorycount' => 'Show Story Count?',
    'showsubmissioncount' => 'Show Submission Count?',
    'hide_home_link' => 'Hide Home Link?',
    'whosonline_threshold' => 'Session Threshold',
    'whosonline_anonymous' => 'Hide Names from Guests?',
    'emailstories' => 'Daily Digest Enabled?',
    'emailstorieslength' => 'Length of Stories',
    'emailstoriesperdefault' => 'Enable for New Users?',
    'allow_domains' => 'Automatic Allow Domains',
    'disallow_domains' => 'Automatic Disallow Domains',
    'newstoriesinterval' => 'New Stories Interval',
    'newcommentsinterval' => 'New Comments Interval',
    'newtrackbackinterval' => 'New Trackbacks Interval',
    'hidenewstories' => 'Hide New Stories',
    'hidenewcomments' => 'Hide New Comments',
    'hidenewtrackbacks' => 'Hide New Trackbacks',
    'hidenewplugins' => 'Hide New Plugin Entries',
    'title_trim_length' => 'Title Trim Length',
    'trackback_enabled' => 'Trackback Enabled?',
    'pingback_enabled' => 'Pingback Enabled?',
    'ping_enabled' => 'Ping Enabled?',
    'trackback_code' => 'Trackback Default',
    'multiple_trackbacks' => 'Multiple Trackbacks',
    'trackbackspeedlimit' => 'Trackback Speed Limit',
    'check_trackback_link' => 'Check Trackbacks',
    'pingback_self' => 'Pingback Self?',
    'pingback_excerpt' => 'Create Pingback Excerpt?',
    'link_documentation' => 'Link to Documentation?',
    'link_versionchecker' => 'Link to Version Checker?',
    'maximagesperarticle' => 'Max Images per Article',
    'limitnews' => 'Stories per Page',
    'minnews' => 'Min. Stories per Page',
    'contributedbyline' => 'Show "Contributed By"?"',
    'hideviewscount' => 'Hide Views Count?',
    'hideemailicon' => 'Hide E-Mail Icon?',
    'hideprintericon' => 'Hide Print Icon?',
    'allow_page_breaks' => 'Allow Page Breaks?',
    'page_break_comments' => 'Comments on Multi-Page Articles',
    'article_image_align' => 'Topic Icon Alignment',
    'show_topic_icon' => 'Show Topic Icon?',
    'draft_flag' => 'Draft Flag Default',
    'frontpage' => 'Frontpage Default',
    'hide_no_news_msg' => 'Hide "No News" Message?',
    'hide_main_page_navigation' => 'Hide Main Page Navigation?',
    'onlyrootfeatures' => 'Only Root can Feature?',
    'aftersave_story' => 'After Saving Story',
    'aftersave_user' => 'After Saving User',
    'show_right_blocks' => 'Always Show Right Blocks?',
    'showfirstasfeatured' => 'Show First Story as Featured?',
    'backend' => 'Enable Feeds?',
    'rdf_file' => 'Syndication Output Folder',
    'rdf_limit' => 'Feed Limit',
    'rdf_storytext' => 'Length of Stories in Feed',
    'rdf_language' => 'Feed Language',
    'syndication_max_headlines' => 'Max. Number of Headlines (portal blocks)',
    'copyrightyear' => 'Copyright Year',
    'image_lib' => 'Image Library',
    'path_to_mogrify' => 'Path to Mogrify',
    'path_to_netpbm' => 'Path to Netpbm',
    'debug_image_upload' => 'Debug Image Uploading?',
    'keep_unscaled_image' => 'Keep Unscaled Image?',
    'allow_user_scaling' => 'Allow User Scaling?',
    'jpeg_quality' => 'JPEG Quality?',
    'max_image_width' => 'Max Image Width?',
    'max_image_height' => 'Max Image Height?',
    'max_image_size' => 'Max Image Size?',
    'max_topicicon_width' => 'Max Topic Icon Width?',
    'max_topicicon_height' => 'Max Topic Icon Height?',
    'max_topicicon_size' => 'Max Topic Icon Size?',
    'max_photo_width' => 'Max Photo Width?',
    'max_photo_height' => 'Max Photo Height?',
    'max_photo_size' => 'Max Photo Size?',
    'use_gravatar' => 'Use Gravatar?',
    'gravatar_rating' => 'Gravatar Rating',
    'force_photo_width' => 'Force Photo Width',
    'default_photo' => 'Default Photo',
    'commentspeedlimit' => 'Comment Speed Limit',
    'comment_limit' => 'Comment Limit',
    'comment_mode' => 'Comment Mode',
    'comment_code' => 'Comment Default',
    'comment_edit' => 'Allow Comment Edit?',
    'comment_edittime' => 'Comment Edit Time (seconds)',
    'commentsubmission' => 'Queue Comment Submissions',
    'passwordspeedlimit' => 'Password Speed Limit',
    'login_attempts' => 'Max. Login Attempts',
    'login_speedlimit' => 'Login Speed Limit',
    'user_html' => 'User HTML',
    'admin_html' => 'Admin HTML',
    'advanced_html' => 'Additional HTML for Adv. Editor',
    'skip_html_filter_for_root' => 'Skip HTML Filter for Root?',
    'allowed_protocols' => 'Allowed Protocols',
    'disable_autolinks' => 'Disable Autotags?',
    'clickable_links' => 'Make URLs clickable?',
    'compressed_output' => 'Send compressed output?',
    'frame_options' => 'Protection against "clickjacking"',
    'censormode' => 'Censor Mode?',
    'censorreplace' => 'Censor Replace Text',
    'censorlist' => 'Censor List',
    'ip_lookup' => 'IP Lookup',
    'url_rewrite' => 'Enable URL Rewrite',
    'meta_tags' => 'Meta Tags',
    'meta_description' => 'Default Meta Description',
    'meta_keywords' => 'Default Meta Keywords',
    'default_permissions_block' => 'Block Default Permissions',
    'default_permissions_story' => 'Story Default Permissions',
    'default_permissions_topic' => 'Topic Default Permissions',
    'atom_max_stories' => 'Max. Stories in Webservices Feed',
    'disable_webservices' => 'Disable Webservices?',
    'restrict_webservices' => 'Restrict Webservices?',
    'article_comment_close_enabled' => 'Automatically close comments (default)',
    'article_comment_close_days' => 'Days to close comments (default)',
    'comment_close_rec_stories' => 'Number of most recent stories enabled for comments',
    'allow_reply_notifications' => 'Allow comment reply notifications?',
    'search_style' => 'Results List Style',
    'search_limits' => 'Page Limits',
    'search_show_num' => 'Show Result Number?',
    'search_show_type' => 'Show Result Type?',
    'search_show_sort' => 'Allow User to Sort Results?',
    'search_show_limit' => 'Show Page Limits?',
    'search_separator' => 'Group Separator',
    'search_def_keytype' => 'Default Search Method',
    'search_def_sort' => 'Default Sort Order'
);

$LANG_configsubgroups['Core'] = array(
    'sg_site' => 'Site',
    'sg_stories' => 'Stories and Trackback',
    'sg_theme' => 'Theme',
    'sg_blocks' => 'Blocks',
    'sg_users' => 'Users and Submissions',
    'sg_images' => 'Images',
    'sg_locale' => 'Languages and Locale',
    'sg_misc' => 'Miscellaneous'
);

$LANG_fs['Core'] = array(
    'fs_site' => 'Site',
    'fs_paths' => 'Paths',
    'fs_theme' => 'Theme',
    'fs_mail' => 'Mail',
    'fs_pear' => 'Pear',
    'fs_mysql' => 'MySQL',
    'fs_users' => 'Users',
    'fs_misc' => 'Miscellaneous',
    'fs_spamx' => 'Spam-X',
    'fs_admin_block' => 'Admin Block',
    'fs_locale' => 'Locale',
    'fs_language' => 'Language',
    'fs_debug' => 'Debug',
    'fs_cookies' => 'Cookies',
    'fs_login' => 'Login Settings',
    'fs_search' => 'Search',
    'fs_user_submission' => 'User Submission',
    'fs_submission' => 'Submission Settings',
    'fs_topics_block' => 'Topics Block',
    'fs_whosonline_block' => 'Who\'s Online Block',
    'fs_daily_digest' => 'Daily Digest',
    'fs_whatsnew_block' => 'What\'s New Block',
    'fs_trackback' => 'Trackback',
    'fs_pingback' => 'Pingback',
    'fs_story' => 'Story',
    'fs_theme_advanced' => 'Advanced Settings',
    'fs_syndication' => 'Syndication',
    'fs_imagelib' => 'Image Library',
    'fs_upload' => 'Upload',
    'fs_articleimg' => 'Images in Articles',
    'fs_topicicon' => 'Topic Icons',
    'fs_userphoto' => 'Photos',
    'fs_gravatar' => 'Gravatar',
    'fs_comments' => 'Comments',
    'fs_htmlfilter' => 'HTML Filtering',
    'fs_censoring' => 'Censoring',
    'fs_iplookup' => 'IP Lookup',
    'fs_perm_story' => 'Story Default Permission',
    'fs_perm_topic' => 'Topic Default Permission',
    'fs_perm_block' => 'Block Default Permission',
    'fs_webservices' => 'Webservices'
);

$LANG_configselects['Core'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false),
    2 => array('Reject' => 0, 'Only Keep Latest' => 1, 'Allow Multiple Posts' => 2),
    3 => array('Trackback Enabled' => 0, 'Trackback Disabled' => -1),
    4 => array('Don\'t Check Anything' => 0, 'Check against Site URL' => 1, 'Check full URL' => 2, 'Check against Site URL and full URL' => 3, 'Check IP against Site IP' => 4, 'Check IP and Site URL' => 5, 'Check IP and Full URL' => 6, 'Check IP, Full URL, and Site URL' => 7),
    5 => array('Plain Old Text' => 'plaintext', 'HTML Formatted' => 'html'),
    6 => array('12' => 12, '24' => 24),
    7 => array('Last Page' => 'last', 'First Page' => 'first', 'Every Page' => 'all'),
    8 => array('Right' => 'right', 'Left' => 'left'),
    9 => array('Forward to page' => 'item', 'Display List' => 'list', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    10 => array('None' => '', 'Netpbm' => 'netpbm', 'ImageMagick' => 'imagemagick', 'gdLib' => 'gdlib'),
    11 => array('Flat' => 'flat', 'Nested' => 'nested', 'Threaded' => 'threaded', 'No Comments' => 'nocomment'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3),
    13 => array('Skip' => 0, 'Allow, with speedlimit' => 1, 'Allow, no speedlimit' => 2),
    14 => array('Sunday' => 'Sun', 'Monday' => 'Mon'),
    15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
    16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3),
    19 => array('Google' => 'google', 'Table' => 'table'),
    20 => array('Exact Phrase' => 'phrase', 'All of The Words' => 'all', 'Any of The Words' => 'any'),
    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => ''),
    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2),
    24 => array('Contribute' => 'contribute', 'Home' => 'home', 'Advanced Search' => 'search', 'Directory' => 'directory', 'My Account' => 'prefs', 'Plugin Entries' => 'plugins', 'Custom Entries' => 'custom', 'Site Statistics' => 'stats'),
    25 => array('New Stories' => 'story', 'New Comments' => 'comment', 'New Trackbacks' => 'trackback', 'New Pingbacks' => 'pingback', 'New Users' => 'user'),
    26 => array('G (General Audiences)' => 'G', 'PG (Parental Guidance)' => 'PG', 'R (Restricted)' => 'R', 'X (Explicit)' => 'X'),
    27 => array('Hits (asc)' => 'hits|asc', 'Hits (desc)' => 'hits|desc', 'Date (asc)' => 'date|asc', 'Date (desc)' => 'date|desc', 'Title (asc)' => 'title|asc', 'Title (desc)' => 'title|desc', 'Author (asc)' => 'uid|asc', 'Author (desc)' => 'uid|desc')
);

?>
